@@ -45,7 +45,9 @@ TEST_AWS_ACCOUNT_ID = os.environ["TEST_AWS_ACCOUNT_ID"]
 MODULE_MAIN_PATH = os.path.dirname(os.path.realpath(__file__))
 # TODO rename to "ROOT_FOLDER"!
 LOCALSTACK_ROOT_FOLDER = os.path.realpath(os.path.join(MODULE_MAIN_PATH, ".."))
-INSTALL_DIR_INFRA = os.path.join(MODULE_MAIN_PATH, "infra")
+INSTALL_DIR_INFRA = os.path.join(
+    MODULE_MAIN_PATH, "infra"
+)  # FIXME: deprecated, use config.dirs.infra
 
 # virtualenv folder
 LOCALSTACK_VENV_FOLDER = os.environ.get("VIRTUAL_ENV")
