@@ -378,11 +378,7 @@ def start_infra(asynchronous=False, apis=None):
                 % config.LAMBDA_EXECUTOR
             )
 
-        if (
-            is_in_docker
-            and not config.LAMBDA_REMOTE_DOCKER
-            and not os.environ.get("HOST_TMP_FOLDER")
-        ):
+        if is_in_docker and not config.LAMBDA_REMOTE_DOCKER and not config.dirs.functions:
             print(
                 "!WARNING! - Looks like you have configured $LAMBDA_REMOTE_DOCKER=0 - "
                 "please make sure to configure $HOST_TMP_FOLDER to point to your host's $TMPDIR"
@@ -513,7 +509,7 @@ def do_start_infra(asynchronous, apis, is_in_docker):
     thread = start_runtime_components()
     preload_services()
 
-    if config.DATA_DIR:
+    if config.dirs.data:
         persistence.save_startup_info()
 
     print(READY_MARKER_OUTPUT)
