@@ -33,6 +33,7 @@ import dns.resolver
 import requests
 import six
 from requests import Response
+from requests.models import CaseInsensitiveDict
 
 import localstack.utils.run
 from localstack import config
@@ -73,6 +74,12 @@ CACHE = {}
 # lock for creating certificate files
 SSL_CERT_LOCK = threading.RLock()
 
+# markers that indicate the start/end of sections in PEM cert files
+PEM_CERT_START = "-----BEGIN CERTIFICATE-----"
+PEM_CERT_END = "-----END CERTIFICATE-----"
+PEM_KEY_START_REGEX = r"-----BEGIN(.*)PRIVATE KEY-----"
+PEM_KEY_END_REGEX = r"-----END(.*)PRIVATE KEY-----"
+
 # regular expression for unprintable characters
 # Based on https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessage.html
 #     #x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF
@@ -475,6 +482,47 @@ class HashableList(list):
         return result
 
 
+class FileMappedDocument(dict):
+    """A dictionary that is mapped to a json document on disk.
+
+    When the document is created, an attempt is made to load existing contents from disk. To load changes from
+    concurrent writes, run load(). To save and overwrite the current document on disk, run save().
+    """
+
+    path: Union[str, os.PathLike]
+
+    def __init__(self, path: Union[str, os.PathLike], mode=0o664):
+        super().__init__()
+        self.path = path
+        self.mode = mode
+        self.load()
+
+    def load(self):
+        if not os.path.exists(self.path):
+            return
+
+        if os.path.isdir(self.path):
+            raise IsADirectoryError
+
+        with open(self.path, "r") as fd:
+            self.update(json.load(fd))
+
+    def save(self):
+        if os.path.isdir(self.path):
+            raise IsADirectoryError
+
+        if not os.path.exists(self.path):
+            mkdir(os.path.dirname(self.path))
+
+        def opener(path, flags):
+            _fd = os.open(path, flags, self.mode)
+            os.chmod(path, mode=self.mode, follow_symlinks=True)
+            return _fd
+
+        with open(self.path, "w", opener=opener) as fd:
+            json.dump(self, fd)
+
+
 # ----------------
 # UTILITY METHODS
 # ----------------
@@ -854,9 +902,13 @@ def merge_recursive(source, destination, none_values=[None], overwrite=False):
             node = destination.setdefault(key, {})
             merge_recursive(value, node, none_values=none_values, overwrite=overwrite)
         else:
-            if not isinstance(destination, dict):
+            if not isinstance(destination, (dict, CaseInsensitiveDict)):
                 LOG.warning(
-                    "Destination for merging %s=%s is not dict: %s", key, value, destination
+                    "Destination for merging %s=%s is not dict: %s (%s)",
+                    key,
+                    value,
+                    destination,
+                    type(destination),
                 )
             if overwrite or destination.get(key) in none_values:
                 destination[key] = value
@@ -1689,17 +1741,17 @@ def generate_ssl_cert(
     def store_cert_key_files(base_filename):
         key_file_name = "%s.key" % base_filename
         cert_file_name = "%s.crt" % base_filename
-        # TODO: Cleaner code to load the cert dinamically
+        # TODO: Cleaner code to load the cert dynamically
         # extract key and cert from target_file and store into separate files
         content = load_file(target_file)
-        key_start = re.search(r"-----BEGIN(.*)PRIVATE KEY-----", content)
+        key_start = re.search(PEM_KEY_START_REGEX, content)
         key_start = key_start.group(0)
-        key_end = re.search(r"-----END(.*)PRIVATE KEY-----", content)
+        key_end = re.search(PEM_KEY_END_REGEX, content)
         key_end = key_end.group(0)
-        cert_start = "-----BEGIN CERTIFICATE-----"
-        cert_end = "-----END CERTIFICATE-----"
         key_content = content[content.index(key_start) : content.index(key_end) + len(key_end)]
-        cert_content = content[content.index(cert_start) : content.rindex(cert_end) + len(cert_end)]
+        cert_content = content[
+            content.index(PEM_CERT_START) : content.rindex(PEM_CERT_END) + len(PEM_CERT_END)
+        ]
         save_file(key_file_name, key_content)
         save_file(cert_file_name, cert_content)
         return cert_file_name, key_file_name
@@ -2022,7 +2074,7 @@ class FileListener:
             finally:
                 tailer.close()
 
-        return FuncThread(func=_run_follow, on_stop=tailer.close)
+        return FuncThread(func=_run_follow, on_stop=lambda *_: tailer.close())
 
 
 # create class-of-a-class
